/*
* Licensed Materials - Property of IBM* and/or HCL**
* UrbanCode Build
* (c) Copyright IBM Corporation 2016, 2017. All Rights Reserved.
* (c) Copyright HCL Technologies Ltd. 2018. All Rights Reserved.
*
* U.S. Government Users Restricted Rights - Use, duplication or disclosure restricted by
* GSA ADP Schedule Contract with IBM Corp.
*
* * Trademark of International Business Machines
* ** Trademark of HCL Technologies Limited
*/

import com.urbancode.air.AirPluginTool
import org.apache.http.client.methods.CloseableHttpResponse
import org.apache.http.util.EntityUtils
import com.urbancode.plugin.ucv.VelocityHelper

AirPluginTool apTool = new AirPluginTool(this.args[0], this.args[1])
Properties props = apTool.getStepProperties()

// -------------------------------------------------------------------------------------------------
// Automation props
// -------------------------------------------------------------------------------------------------
String velocityUrl = props["automation/velocityUrl"]
String accessKey = props["automation/accessKey"]
String tenantId = props["automation/tenantId"]

// -------------------------------------------------------------------------------------------------
// Environment props
// -------------------------------------------------------------------------------------------------
String buildLifeId = System.getenv("BUILD_LIFE_ID")
String ucbUrl = System.getenv("WEB_URL")

// -------------------------------------------------------------------------------------------------
// Step props
// -------------------------------------------------------------------------------------------------
String buildName = props["buildName"]
String versionName = props["versionName"]
String status = props["status"]
String appName = props["applicationName"]
String workspaceDate = props["job/workspace.date"]
String requester = props["requesterName"]

// Only the very first workspace.revision.* property is considered to set the revision value. If there are multiple
// source configs, there will be multiple properties for workspace.revision.* and we currently skip over the other values.
String revision = ""
for (entry in props) {
    String key = entry.key
    if (key?.startsWith("buildlife/workspace.revision")) {
        revision = entry.value
        break
    }
}

if (!revision) {
    println "Unable to find a value for revision."
}

CloseableHttpResponse response = null

try {
    println("Uploading Build Info to UrbanCode Velocity...")

    VelocityHelper helper = new VelocityHelper(velocityUrl, accessKey)
    response = helper.uploadBuildData(buildLifeId, tenantId, buildName, versionName, status, appName, ucbUrl, revision,
            workspaceDate, requester)
    String responseString = EntityUtils.toString(response.getEntity())

    int statusCode = response.getStatusLine().getStatusCode()
    if (statusCode < 200 || statusCode >= 300) {
        throw new RuntimeException("Bad response when uploading metrics file: $statusCode - $responseString")
    }
    println("Response: $responseString")
    println("Successfully uploaded metrics data.")
}
finally {
    if (response) {
        response.close()
    }
}